@@ -50,29 +50,101 @@ weights=NULL
 	} else if(style=='fixed') {
 		x = NULL
 	} else if(style=='unique') {
-		levelsx = levels(x)[[1]]
-		if(!is.null(levelsx)) {
-			if(all(c("col","ID","label")%in% names(levelsx))) {
-				breaks = levelsx$ID
-				col=levelsx$col
-				labels=levelsx$labels
-			}
-				
-		}
+
+    if(is.null(labels)){
+      levelsx = levels(x)[[1]]
+    } else {
+      # if labels is a data frame, use it
+      if(is.data.frame(labels)) {
+        levelsx = labels
+      } else if(
+          length(labels) == length(breaks)
+          ){
+        levelsx = data.frame(
+            ID=breaks,
+            label=as.character(labels)
+            )
+      } else { # different number of labels and breaks
+        levelsx = data.frame(
+            ID=sort(unique(x))
+            )
+        if(ncol(levelsx)==length(labels)) {
+          levelsx$label = as.character(labels)
+        } else {
+          warning('labels must be same length as either breaks or unique(x)')
+          levelsx$label = as.character(levelsx$ID)
+        }
+      } # end different numbers of levels and breaks
+      
+  } # labels is not null
+    
+    if(ncell(x)<1e+06) {
+      x = freq(x)
+      weights = x[,2]
+      x=x[,1]
+    } else {
+      x = table(
+              sampleRegular(x, 5e+05)
+      )
+      weights = x
+      x = as.numeric(names(x))
+    }
+    
+    if(is.null(levelsx)){
+      levelsx = data.frame(
+          ID=sort(x))
+    }
+    notInLevels = which(! x %in% levelsx$ID)
+    if(length(notInLevels)){
+      # add more values to ID
+      toAdd = matrix(NA,
+          length(notInLevels),ncol(levelsx), 
+          dimnames=list(NULL, colnames(levelsx)))
+      toAdd[,1] = x[notInLevels]
+    levelsx = rbind(levelsx, toAdd)
+    levelsx = levelsx[order(levelsx$ID),]
+    } # end add more ID in levels
+    if(is.vector(labels)){
+      if(length(labels)==nrow(levelsx))
+        levelsx$label = labels
+    } # end labels are vector
+    if(is.null(levelsx$label))
+      levelsx$label = as.character(levelsx$ID)
+    
+    levelsx$freq = weights[match(
+            levelsx$ID,
+            x
+            )]
+  # if more breaks than ID's have been requested
+  # set breaks to all ID's
+  if(length(breaks)==1 & all(breaks > nrow(levelsx)))
+    breaks = levelsx$ID
+  
+  if((
+        length(breaks)==nrow(levelsx)
+        ) & (
+        'col' %in% names(levelsx)
+        )
+  ){
+   # colours have been provided 
+    col = levelsx$col
+  }
+  
+  weights = levelsx$freq
+  x=levelsx$ID
+  labels = levelsx$label
 		
-		if(ncell(x)<10^6) {
-			x = freq(x)
-			weights = x[,2]
-			x=x[,1]
-		} else {
-			x = table(sampleRegular(x, 50000))
-			weights = x
-			x = as.numeric(names(x))
-		}
-		
-		
-	} else {
-		x = sampleRegular(x, min(c(ncell(x),10000)))
+	} else { # not unique or equal or fixed, take a sample
+    Nsample = 20000
+    xVec= c()
+    Diter = 0
+    while(length(xVec)<Nsample & Diter < 5){
+      xVec = c(xVec,
+          na.omit(sampleRegular(x, min(c(ncell(x),Nsample))))
+      )
+      Diter = Diter + 1
+    }
+    x = c(xVec, maxValue(x), minValue(x))
 	}
 	res=colourScale(x, breaks, 
 			style,
@@ -139,6 +211,13 @@ colourScale.numeric = function(x=NULL, breaks=5,
     if(length(breaks)==1){
       # breaks is the maximum number of breaks
       thetable = thetable[order(thetable$Freq, decreasing=TRUE),]
+      
+      shouldExclude = which(thetable$ID %in% exclude)
+      if(length(shouldExclude))
+        thetable = rbind(
+          thetable[-shouldExclude,],
+          thetable[shouldExclude,]
+          )
       breaks = thetable[
           seq(1,min(breaks,nrow(thetable))),'ID'
           ]
@@ -152,10 +231,10 @@ colourScale.numeric = function(x=NULL, breaks=5,
 						Freq=rep(0,length(notInX)))
 				)
 				
-		if(length(labels)== length(breaks)) {
+		if(length(labels) == length(breaks)) {
 			thetable$label = labels[match(thetable$ID,breaks)]
 		} else {
-			if(length(labels)== length(xOrig)) {
+			if(length(labels) == length(xOrig)) {
 				thetable$label = labels[match(thetable$ID,xOrig)]
 			} else if(length(labels)==nrow(thetable)){
 				thetable$label = labels[order(thetable$ID)]
@@ -178,6 +257,7 @@ colourScale.numeric = function(x=NULL, breaks=5,
 		
 		thetable[match( breaks, thetable$ID),'col'] = col(length(breaks))
 		thetable = thetable[order(thetable$ID),]
+
 		
 		colVec = thetable$col
 		names(colVec) =as.character(thetable$ID)
@@ -323,7 +403,7 @@ colourScale.numeric = function(x=NULL, breaks=5,
 			result$plot = thetable[match(xOrig, thetable$ID),'colOpacity']
 		result$levels = thetable
 		if(length(thetable$label))
-			result$legend = thetable$label
+			result$legend = as.character(thetable$label)
 	} else if (length(xOrig)){		
 		result$plot = as.character(cut(
 						xOrig, 
