@@ -4,28 +4,36 @@ osmTiles = function(name) {
 			"osm-no-labels"="http://a.tiles.wmflabs.org/osm-no-labels/",
       "osm-de"="http://c.tile.openstreetmap.de/tiles/osmde",
 			"osm-transport"="http://tile2.opencyclemap.org/transport/",
-			"bw-mapnik"="http://b.tiles.wmflabs.org/bw-mapnik2",
+			"bw-mapnik"="http://b.tiles.wmflabs.org/bw-mapnik",
 			mapquest="http://otile1.mqcdn.com/tiles/1.0.0/osm/",
 			"mapquest-sat"="http://otile1.mqcdn.com/tiles/1.0.0/sat",
       "mapquest-labels"='http://otile3.mqcdn.com/tiles/1.0.0/hyb/',
-#			hill="http://www.toolserver.org/~cmarqu/hill/",
-			landscape="http://tile.opencyclemap.org/landscape/",
+      'osm-cyclemap' = 'http://a.tile.opencyclemap.org/cycle/',
+      'osm-seamap' = 'http://tiles.openseamap.org/seamark/',
+      'osm-fr' = 'http://a.tile.openstreetmap.fr/osmfr/',
+#      'osm-rail' = 'http://a.tiles.openrailwaymap.org/standard/',
+# rail is 512 insstead of 256 tiles
+      #			hill="http://www.toolserver.org/~cmarqu/hill/",
+			'landscape'="http://tile.opencyclemap.org/landscape/",
 #		"osm-retina"="http://tile.geofabrik.de/osm_retina/",
 		"opentopomap" = "http://opentopomap.org/tiles/",
 #		"osm2world"="http://tiles.osm2world.org/osm/pngtiles/n/",
 #		bvg="http://mobil.bvg.de/tiles/",
-#	esri="http://server.arcgisonline.com/ArcGIS/rest/services/World_Street_Map/MapServer/tile/",
-#	"esri-sat"="http://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/",
 #	landshaded="http://tiles.openpistemap.org/landshaded/",
 	"maptoolkit"="http://tile2.maptoolkit.net/terrain/",
-#	skobbler="http://tiles.skobbler.net/osm_tiles2/",	
+#	skobbler="http://tiles3.skobbler.net/osm_tiles2/",	
+#  'sputnik' = 'http://a.tiles.maps.sputnik.ru/tiles/kmt2/',
 	waze="http://tilesworld.waze.com/tiles/",
+  'waze-us'='http://livemap-tiles1.waze.com/tiles/',
 #	eu="http://alpha.map1.eu/tiles/"#,
-#	mapbox="http://a.tiles.mapbox.com/v3/examples.map-vyofok3q/",
 	humanitarian="http://a.tile.openstreetmap.fr/hot/",
-cartodb='http://c.basemaps.cartocdn.com/light_all/',
+ cartodb='http://c.basemaps.cartocdn.com/light_all/',
 'cartodb-dark'='http://c.basemaps.cartocdn.com/dark_all/',
-historical='http://www.openhistoricalmap.org/ohm_tiles/'
+historical='http://www.openhistoricalmap.org/ohm_tiles/'#,
+#'esri' = 'http://services.arcgisonline.com/ArcGIS/rest/services/World_Street_Map/MapServer/tile/',
+#' 'esri-grey' = 'http://services.arcgisonline.com/ArcGIS/rest/services/Canvas/World_Light_Gray_Base/MapServer/tile/',
+#' 'esri-transport'='http://server.arcgisonline.com/ArcGIS/rest/services/Reference/World_Transportation/MapServer/tile/',
+#' 'esri-topo' = 'http://services.arcgisonline.com/ArcGIS/rest/services/World_Topo_Map/MapServer/tile/'
 	)
 	
 	
@@ -60,7 +68,7 @@ openmap = function(x, zoom,
 	path="http://tile.openstreetmap.org/",
 	maxTiles = 9,
 	crs=projection(x),
-  extend=0,
+  buffer=0,
 	verbose=FALSE) {
 
 
@@ -79,34 +87,31 @@ openmap = function(x, zoom,
 						path[ grep("^http[s]*://", path, invert=TRUE)], sep="")
 	names(pathOrig) = path
 
-	extLL = .extentLL(x,crs, extend)
-
-		
-	if(any(abs(as.vector(extLL))>181))
-		warning("no CRS supplied and coordinates do not appear to be long-lat")
-		
-	xlim= c(xmin(extLL), xmax(extLL))
-	ylim = c(ymin(extLL), ymax(extLL))
-		
+	extMerc = .getExtent(x,crs, buffer, crsMercSphere)
+  extMerc = cropExtent(extMerc, openmapExtentMercSphere)
+  
 	if(missing(zoom)) {
 	zoom = 1
-	while(nTiles(xlim, ylim, zoom) <= maxTiles & zoom <= 18) {
+	while(nTilesMerc(extMerc, zoom) <= maxTiles & zoom <= 18) {
 		zoom = zoom + 1
 	}
 	zoom = min(c(18,max(c(1, zoom-1))))
 	}
-	if(verbose) cat("zoom is ", zoom, ", ", nTiles(xlim, ylim, zoom), "tiles\n")
+	if(verbose) cat("zoom is ", zoom, ", ", nTilesMerc(extMerc, zoom), "tiles\n")
 
 	result = NULL
+
+  
 	for(Dpath in rev(path)) {
 		thistile = try(
-				getTiles(xlim,ylim, zoom=zoom,
+				getTilesMerc(extMerc, zoom=zoom,
 				path=Dpath,
 				verbose=verbose),
 		silent=TRUE	)
 
 		if(class(thistile)=="try-error"){
 			message(paste(Dpath, "not accessible"))
+      thistile=NULL
 		}	else {
 			if(length(names(thistile))) {
 				theprefix=strsplit(names(thistile), "([rR]ed|[gG]reen|[bB]lue)$",fixed=FALSE)[[1]]
@@ -129,7 +134,7 @@ openmap = function(x, zoom,
 
 	
 	if(is.null(result)) {
-		result = raster(extLL,1,1,crs=crsLL)
+		result = raster(openmapExtentMercSphere,1,1,crs=crsMercSphere)
 		values(result) = NA
     attributes(result)$openmap = list(
         tiles=NA,
@@ -142,8 +147,10 @@ openmap = function(x, zoom,
 	crsOut=crs
 	
 	if(!is.na(crsOut)  ){
+    if(verbose) cat("reprojecting ", ncell(result), " cells...")
     
 		resultProj = projectRaster(result, crs=crsOut, method="ngb")
+    if(verbose) cat("done\n")
     
 	} else {
 		resultProj = result
@@ -167,7 +174,7 @@ openmap = function(x, zoom,
       values(resultProj[[D]]) = 1+values(resultProj[[D]])
 	}
 }
-}
+} # end D in names(resultProj)
 
 	if(nlayers(resultProj)==1) 
 		resultProj = resultProj[[1]]
